const router = require('express').Router();
const User = require('../models/User');
const secureRoute = require("../middleware/secureRoute");

router.post('/', async (req, res) => {
    try {
        const user = new User(req.body);

        user.generateToken();
        await user.save();

        res.send(user);
    } catch (e) {
        res.status(400).send(e);
    }
});

router.post('/login', async (req, res) => {
    const user = await User.findOne({username: req.body.username});

    if (!user) return res
        .status(400)
        .send({error: 'Username or password incorrect'});

    if (!await user.checkPassword(req.body.password.toString())) return res
        .status(400)
        .send({error: 'Username or password incorrect'});

    try {
        user.generateToken();
        await user.save();

        res.send(user);
    } catch (e) {
        res
            .status(400)
            .send({error: e.message});
    }
});

router.get('/profile', secureRoute, async (req, res) => {
    const token = req.get('Authorization');
    const user = await User.findOne({token});

    res.send({
       message: "Большой большой сикрет",
       username: user.username
    });
});

router.delete('/logout', secureRoute, async (req, res) => {
    const token   = req.get('Authorization');
    const success = {message: 'Success'};
    const user    = await User.findOne({token});

    user.token = null;
    user.save();

    res.send(success);
});

module.exports = router;
