import {useState} from "react";
import {Button, Grid, TextField} from "@mui/material";
import FileInput from "../../UI/Form/FormElement/FileInput/FileInput";

const ProductForm = ({createProductHandler}) => {
    const [state, setState] = useState({
        title: "",
        price: "",
        description: "",
        image: ''
    });

    const submitFormHandler = e => {
        e.preventDefault();

        const formData = new FormData();

        Object.keys(state).forEach(key => {
            formData.append(key, state[key]);
        });

        createProductHandler(formData);
    };

    const inputChangeHandler = e => {
        const name = e.target.name;
        const value = e.target.value;

        setState(prevState => {
            return {...prevState, [name]: value};
        });
    };

    const onFileChangeHandler = e => {
        const file = e.currentTarget.files[0];
        const name = e.currentTarget.name;

        setState(prevState => {
            return {...prevState, [name]: file};
        });
    };

    return (
        <form
            autoComplete="off"
            onSubmit={submitFormHandler}
        >
            <Grid container direction="column" spacing={2}>
                <Grid item xs>
                    <TextField
                        fullWidth
                        variant="outlined"
                        id="title"
                        label="Title"
                        value={state.title}
                        onChange={inputChangeHandler}
                        name="title"
                    />
                </Grid>
                <Grid item xs>
                    <TextField
                        fullWidth
                        variant="outlined"
                        id="price"
                        label="Price"
                        value={state.price}
                        onChange={inputChangeHandler}
                        name="price"
                    />
                </Grid>
                <Grid item xs>
                    <TextField
                        fullWidth
                        multiline
                        rows={3}
                        variant="outlined"
                        id="description"
                        label="Description"
                        value={state.description}
                        onChange={inputChangeHandler}
                        name="description"
                    />
                </Grid>
                <Grid item xs>
                    <FileInput
                        onChange={onFileChangeHandler}
                        name="image"
                        label="Image"
                    />
                </Grid>
                <Grid item xs>
                    <Button type="submit" color="primary" variant="contained">Create</Button>
                </Grid>
            </Grid>
        </form>
    );
};

export default ProductForm;
